==> process-kafka-quickstart-springboot-0.10.0-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.PDD.LambdaPredicateDD9499A84F79CACDABB63CBD3A8D49B6.INSTANCE,
                                                                                                       D.alphaIndexedBy(java.lang.Boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PED.LambdaExtractorED7FA8BA892C2C21FB3FA68D21A73AFE.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.PAA.LambdaPredicateAA1849352A22D7AEEAA095F08A02CB1D.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.PD3.LambdaExtractorD33A1642777DA894E7356045563AC333.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.P94.LambdaConsequence941952762A597E3A1C3969F7277FF0E2.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.PDD.LambdaPredicateDD9499A84F79CACDABB63CBD3A8D49B6.INSTANCE,
                                                                                                                     D.alphaIndexedBy(java.lang.Boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PED.LambdaExtractorED7FA8BA892C2C21FB3FA68D21A73AFE.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.P89.LambdaPredicate8996D0C869205369BC53F5F813C17206.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.PD3.LambdaExtractorD33A1642777DA894E7356045563AC333.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.P7E.LambdaConsequence7E7E820C57F7F133FBE33130A44A2C11.INSTANCE));
        return rule;
    }
}

==> process-kafka-quickstart-springboot-0.12.0-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.P7D.LambdaPredicate7D2A647EB797383C850CDA93CC1385BA.INSTANCE,
                                                                                                       D.alphaIndexedBy(java.lang.Boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PED.LambdaExtractorED7FA8BA892C2C21FB3FA68D21A73AFE.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.P15.LambdaPredicate1525ABC6DBF0BE6A28C1EE7D7AB403DB.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.PD3.LambdaExtractorD33A1642777DA894E7356045563AC333.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.P94.LambdaConsequence941952762A597E3A1C3969F7277FF0E2.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.P7D.LambdaPredicate7D2A647EB797383C850CDA93CC1385BA.INSTANCE,
                                                                                                                     D.alphaIndexedBy(java.lang.Boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PED.LambdaExtractorED7FA8BA892C2C21FB3FA68D21A73AFE.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.P63.LambdaPredicate63FAF9FA5E10B1C4568BCD0A32F8591A.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.PD3.LambdaExtractorD33A1642777DA894E7356045563AC333.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.P7E.LambdaConsequence7E7E820C57F7F133FBE33130A44A2C11.INSTANCE));
        return rule;
    }
}
